"""
API module grouping all the mlab functions to manipulate directly the
pipeline.

"""

# Author: Gael Varoquaux <gael.varoquaux@normalesup.org>
# Copyright (c) 2007-2009, Enthought, Inc. 
# License: BSD Style.

from modules import *
from sources import *
from filters import *
from tools import add_dataset, set_extent, add_module_manager, \
    get_vtk_src
from tools import _traverse as traverse

